@@ -83,6 +83,9 @@ def select_relevant_features(X, y, tree_model=xgb):
             estimator=tree_model,
             n_estimators="auto",
             max_iter=50,  # number of trials to perform
+            perc=80,
+            alpha=0.05,
+            two_step=False
         )
 
     # fit Boruta (it accepts np.array, not pd.DataFrame)
