@@ -194,22 +194,34 @@ def objective(trial, df, study_name, model_mode):
 
 
 
+
+
+    data_dir = os.path.join(os.getcwd(), "data")
+    Path(data_dir).mkdir(parents=True, exist_ok=True)
+    X_test = get_config('X_test')
+    y_test = get_config('y_test')
+    df_test = X_test.join(y_test)
+    df_test.to_csv(os.path.join(data_dir, 'test.csv'))
+    mlflow.log_artifact(data_dir)
+
+
     dashboard_dir = os.path.join(os.getcwd(), "dashboard")
     Path(dashboard_dir).mkdir(parents=True, exist_ok=True)
 
-    X_test = get_config('X_test')
-    y_test = get_config('y_test')
+    try:
+        explainer = ClassifierExplainer(model, X_test, y_test)
+        db = ExplainerDashboard(explainer, 
+                            # defaults to "Model Explainer"
+                            whatif=False,
+                            shap_interaction=False
+                            )
 
-    explainer = ClassifierExplainer(model, X_test, y_test)
-    db = ExplainerDashboard(explainer, 
-                         # defaults to "Model Explainer"
-                        whatif=False,
-                        shap_interaction=False
-                        )
+        db.save_html(os.path.join(dashboard_dir, 'dash.html'))
 
-    db.save_html(os.path.join(dashboard_dir, 'dash.html'))
-
-    mlflow.log_artifact(dashboard_dir)
+        mlflow.log_artifact(dashboard_dir)
+    except:
+        pass
+    
 
     
 
